# boot_django.py
#
# This file sets up and configures Django. It's used by scripts that need to
# execute as if running in a Django server.
import os
import django
from django.conf import settings

BASE_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), "base_datos"))

def boot_django():
    settings.configure(
        BASE_DIR=BASE_DIR,
        DEBUG=True,
        DATABASES = {
            'default': {
                'ENGINE': 'django.db.backends.mysql',
                'NAME': 'test',
                'USER': 'root',
                'PASSWORD': 'admin',
                'HOST': 'localhost',
                'PORT': '3306',
            },
        },
        INSTALLED_APPS=(
            "base_datos",
        ),
        TIME_ZONE="UTC",
        USE_TZ=True,
    )
    django.setup()


from django.db import models
# from .managers import PersonaManager


class Persona(models.Model):
    nombre = models.CharField(db_column='Nombre', primary_key=True, max_length=50)  # Field name made lowercase.
    apellido = models.CharField(db_column='Apellido', max_length=45, blank=True, null=True)  # Field name made lowercase.
    telefono = models.IntegerField(db_column='Telefono', blank=True, null=True)  # Field name made lowercase.

    # persona_manager = PersonaManager()

    class Meta:
        managed = False
        db_table = 'persona'
